document.getElementById("Contents").innerHTML='\
    <ul><li><input type="checkbox" id="07"><label for="07">Makro dan Pemrograman</label><ul>\
    <li><input type="checkbox" id="0701"><label for="0701">Informasi Umum dan Penggunaan Antar Muka Pengguna</label><ul>\
    <li><a target="_top" href="id/text/sbasic/shared/main0601.html">Bantuan LibreOffice Basic</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/01000000.html">Pemrograman dengan LibreOffice Basic</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/00000002.html">Daftar Kata LibreOffice Dasar</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/01010210.html">Dasar</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/01020000.html">Sintaksis</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/01050000.html">IDE LibreOffice Basic</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/01030100.html">Ikhtisar IDE</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/01030200.html">Editor Basic</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/01050100.html">Jendela Pengawas</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/main0211.html">Baris Alat Makro</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/05060700.html">Makro</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/vbasupport.html">Support for VBA Macros</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0702"><label for="0702">Rujukan Perintah</label><ul>\
    <li><a target="_top" href="id/text/sbasic/shared/01020300.html">Menggunakan Prosedur dan Fungsi</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/01020500.html">Pustaka, Modul, dan Dialog</a></li>\
    <li><input type="checkbox" id="070202"><label for="070202">Fungsi, Statement, dan Operator</label><ul>\
    <li><a target="_top" href="id/text/sbasic/shared/03010000.html">Screen I/O Functions</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020000.html">File I/O Functions</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030000.html">Fungsi Tanggal dan Waktu</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03050000.html">Error-Handling Functions</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03060000.html">Operator Logika</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03070000.html">Operator Matematika</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03080000.html">Fungsi Numerik</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03090000.html">Mengontrol Eksekusi Program</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03100000.html">Variabel</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03040000.html">Basic Constants</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03110000.html">Operator Pembanding</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120000.html">String</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/special_vba_func.html">Exclusive VBA functions</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03130000.html">Perintah Lainnya</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="070201"><label for="070201">Daftar Alfabetis dari Fungsi, Statement, dan Operator</label><ul>\
    <li><a target="_top" href="id/text/sbasic/shared/03080601.html">Abs Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03060100.html">AND Operator</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03104200.html">Array Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120101.html">Asc Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120111.html">AscW Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03080101.html">Atn Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03130100.html">Beep Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03010301.html">Blue Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03100100.html">CBool Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120105.html">CByte Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03100050.html">CCur Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030116.html">CDateFromUnoDateTime Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030115.html">CDateToUnoDateTime Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030114.html">CDateFromUnoTime Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030113.html">CDateToUnoTime Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030112.html">CDateFromUnoDate Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030111.html">CDateToUnoDate Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030108.html">CDateFromIso Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030107.html">CDateToIso Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03100300.html">CDate Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03100400.html">CDbl Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03100060.html">CDec Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03100500.html">CInt Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03100600.html">CLng Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03100900.html">CSng Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03101000.html">CStr Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03090401.html">Call Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020401.html">ChDir Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020402.html">ChDrive Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03090402.html">Choose Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120102.html">Chr Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120112.html">ChrW Function [VBA]</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020101.html">Close Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03110100.html">Comparison Operators</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03100700.html">Const Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120313.html">ConvertFromURL Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120312.html">ConvertToURL Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03080102.html">Cos Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03132400.html">CreateObject Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03131800.html">CreateUnoDialog Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03132000.html">CreateUnoListener Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03131600.html">CreateUnoService Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03131500.html">CreateUnoStruct Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03132300.html">CreateUnoValue Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020403.html">CurDir Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03100070.html">CVar Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03100080.html">CVErr Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030110.html">DateAdd Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030120.html">DateDiff Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030130.html">DatePart Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030101.html">DateSerial Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030102.html">DateValue Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030301.html">Date Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030103.html">Day Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03140000.html">DDB Function [VBA]</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03090403.html">Declare Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03101100.html">DefBool Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03101300.html">DefDate Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03101400.html">DefDbl Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03101500.html">DefInt Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03101600.html">DefLng Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03101700.html">DefObj Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03102000.html">DefVar Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03104300.html">DimArray Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03102100.html">Dim Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020404.html">Dir Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03090201.html">Do...Loop Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03110100.html">Comparison Operators</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03090404.html">End Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03130800.html">Environ Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020301.html">Eof Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03104600.html">EqualUnoObjects Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03060200.html">Eqv Operator</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03050100.html">Erl Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03050200.html">Err Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03050300.html">Error Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03050000.html">Error-Handling Functions</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03090412.html">Exit Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03080201.html">Exp Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020405.html">FileAttr Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020406.html">FileCopy Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020407.html">FileDateTime Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020415.html">FileExists Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020408.html">FileLen Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03103800.html">FindObject Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03103900.html">FindPropertyObject Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03080501.html">Fix Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03090202.html">For...Next Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120301.html">Format Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03150000.html">FormatDateTime Function [VBA]</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020102.html">FreeFile Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03090405.html">FreeLibrary Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03090406.html">Function Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03090400.html">Further Statements</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03140001.html">FV Function [VBA]</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03080300.html">Menghasilkan Angka Acak</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020409.html">GetAttr Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03132500.html">GetDefaultContext Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03132100.html">GetGuiType Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03131700.html">GetProcessServiceManager Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03131000.html">GetSolarVersion Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03130700.html">GetSystemTicks Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020201.html">Get Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03131900.html">GlobalScope</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03090301.html">GoSub...Return Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03090302.html">GoTo Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03010302.html">Green Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03104400.html">HasUnoInterfaces Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03080801.html">Hex Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030201.html">Hour Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03090103.html">IIf Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03090101.html">If...Then...Else Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03060300.html">Imp Operator</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120401.html">InStr Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120411.html">InStrRev Function [VBA]</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03160000.html">Input Function [VBA]</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03010201.html">InputBox Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020202.html">Input# Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03080502.html">Int Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03140002.html">IPmt Function [VBA]</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03140003.html">IRR Function [VBA]</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03102200.html">IsArray Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03102300.html">IsDate Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03102400.html">IsEmpty Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03104000.html">IsMissing function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03102600.html">IsNull Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03102700.html">IsNumeric Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03102800.html">IsObject Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03104500.html">IsUnoStruct Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120315.html">Join Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020410.html">Kill Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03102900.html">LBound Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120302.html">LCase Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120304.html">LSet Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120305.html">LTrim Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120303.html">Left Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120402.html">Len Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03103100.html">Let Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020203.html">Line Input # Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020302.html">Loc Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020303.html">Lof Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03080202.html">Log Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120306.html">Mid Function, Mid Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030202.html">Minute Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03140004.html">MIRR Function [VBA]</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020411.html">MkDir Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03070600.html">Mod Operator</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030104.html">Month Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03150002.html">MonthName Function [VBA]</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03010102.html">MsgBox Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03010101.html">MsgBox Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020412.html">Name Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03060400.html">Not Operator</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030203.html">Now Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03140005.html">NPer Function [VBA]</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03140006.html">NPV Function [VBA]</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03080000.html">Fungsi Numerik</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03080802.html">Oct Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03050500.html">On Error GoTo ... Resume Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03090303.html">On...GoSub Statement; On...GoTo Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020103.html">Open Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03103200.html">Option Base Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03103300.html">Option Explicit Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03103350.html">Option VBASupport Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03104100.html">Optional (in Function Statement)</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03060500.html">Or Operator</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03140007.html">Pmt Function [VBA]</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03140008.html">PPmt Function [VBA]</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03140009.html">PV Function [VBA]</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03010103.html">Print Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03103400.html">Public Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020204.html">Put Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03010304.html">QBColor Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03140010.html">Rate Function [VBA]</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03010305.html">RGB Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120308.html">RSet Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120309.html">RTrim Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03080301.html">Randomize Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03102101.html">ReDim Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03010303.html">Red Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03090407.html">Rem Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020104.html">Reset Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120307.html">Right Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020413.html">RmDir Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03080302.html">Rnd Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03170000.html">Round Function [VBA]</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030204.html">Second Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020304.html">Seek Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020305.html">Seek Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03090102.html">Select...Case Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020414.html">SetAttr Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03103700.html">Set Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03080701.html">Sgn Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03130500.html">Shell Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03080103.html">Sin Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03140011.html">SLN Function [VBA]</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120201.html">Space Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120314.html">Split Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03080401.html">Sqr Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03080400.html">Kalkulasi Akar</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03103500.html">Static Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03090408.html">Stop Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120403.html">StrComp Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120103.html">Str Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120412.html">StrReverse Function [VBA]</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120202.html">String Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03090409.html">Sub Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03090410.html">Switch Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03140012.html">SYD Function [VBA]</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03080104.html">Tan Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030205.html">TimeSerial Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030206.html">TimeValue Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030302.html">Time Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030303.html">Timer Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03080100.html">Fungsi Triginometri</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120311.html">Trim Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03131300.html">TwipsPerPixelX Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03131400.html">TwipsPerPixelY Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03090413.html">Type Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03103600.html">TypeName Function; VarType Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03103000.html">UBound Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120310.html">UCase Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03120104.html">Val Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03130600.html">Wait Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030105.html">WeekDay Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03150001.html">WeekdayName Function [VBA]</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03090203.html">While...Wend Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03090411.html">With Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03020205.html">Write Statement</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03060600.html">XOR Operator</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03030106.html">Year Function</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03070100.html">"-" Operator</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03070200.html">"*" Operator</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03070300.html">"+" Operator</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03070400.html">"/" Operator</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03070500.html">"^" Operator</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="070205"><label for="070205">Pustaka Dasar Lanjutan</label><ul>\
    <li><a target="_top" href="id/text/sbasic/shared/03/lib_tools.html">Tools Library</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03/lib_depot.html">DEPOT Library</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03/lib_euro.html">EURO Library</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03/lib_formwizard.html">FORMWIZARD Library</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03/lib_gimmicks.html">GIMMICKS Library</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03/lib_schedule.html">SCHEDULE Library</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03/lib_script.html">SCRIPTBINDINGLIBRARY Library</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/03/lib_template.html">TEMPLATE Library</a></li>\
			</ul></li>\
                    </ul></li>\
    <li><input type="checkbox" id="0703"><label for="0703">Panduan</label><ul>\
    <li><a target="_top" href="id/text/shared/guide/macro_recording.html">Recording a Macro</a></li>\
    <li><a target="_top" href="id/text/sbasic/guide/control_properties.html">Mengubah Properti Kontrol dalam Editor Dialog</a></li>\
    <li><a target="_top" href="id/text/sbasic/guide/insert_control.html">Membuat Kontrol pada Editor Dialog</a></li>\
    <li><a target="_top" href="id/text/sbasic/guide/sample_code.html">Contoh Pemrograman untuk Kontrol di Editor Dialog</a></li>\
    <li><a target="_top" href="id/text/sbasic/guide/show_dialog.html">Membuka Dialog dengan Kode Program</a></li>\
    <li><a target="_top" href="id/text/sbasic/guide/create_dialog.html">Membuat Dialog Dasar</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/01030400.html">Mengorganisasikan Pustaka dan Modul</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/01020100.html">Menggunakan Variabel</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/01020200.html">Menggunakan Objek</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/01030300.html">Memburu Hama Kode ("Debugging") Program Basic</a></li>\
    <li><a target="_top" href="id/text/sbasic/shared/01040000.html">Event-Driven Macros</a></li>\
    <li><a target="_top" href="id/text/sbasic/guide/access2base.html">Access2Base</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="08"><label for="08">Lembar Kerja</label><ul>\
    <li><input type="checkbox" id="0801"><label for="0801">Informasi Umum dan Penggunaan Antar Muka Pengguna</label><ul>\
    <li><a target="_top" href="id/text/scalc/main0000.html">Selamat datang di Bantuan LibreOffice Calc</a></li>\
    <li><a target="_top" href="id/text/scalc/main0503.html">Fitur LibreOffice Calc</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/keyboard.html">Shortcut Keys (LibreOffice Calc Accessibility)</a></li>\
    <li><a target="_top" href="id/text/scalc/04/01020000.html">Tombol Pintas untuk Pengolah Angka</a></li>\
    <li><a target="_top" href="id/text/scalc/05/02140000.html">Kode Kesalahan dalam LibreOffice Calc</a></li>\
    <li><a target="_top" href="id/text/scalc/01/04060112.html">Tambahan bagi Pemrograman LibreOffice Calc</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/main.html">Instruksi dalam Menggunakan LibreOffice Calc</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0802"><label for="0802">Rujukan Menu dan Perintah</label><ul>\
    <li><input type="checkbox" id="080201"><label for="080201">Menu</label><ul>\
    <li><a target="_top" href="id/text/scalc/main0100.html">Menu</a></li>\
    <li><a target="_top" href="id/text/scalc/main0101.html">Berkas</a></li>\
    <li><a target="_top" href="id/text/scalc/main0102.html">Sunting</a></li>\
    <li><a target="_top" href="id/text/scalc/main0103.html">Tampilan</a></li>\
    <li><a target="_top" href="id/text/scalc/main0104.html">Sisip</a></li>\
    <li><a target="_top" href="id/text/scalc/main0105.html">Format</a></li>\
    <li><a target="_top" href="id/text/scalc/main0116.html">Lembar Kerja</a></li>\
    <li><a target="_top" href="id/text/scalc/main0112.html">Data</a></li>\
    <li><a target="_top" href="id/text/scalc/main0106.html">Perkakas</a></li>\
    <li><a target="_top" href="id/text/scalc/main0107.html">Jendela</a></li>\
    <li><a target="_top" href="id/text/shared/main0108.html">Bantuan</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="080202"><label for="080202">Bilah alat</label><ul>\
    <li><a target="_top" href="id/text/scalc/main0200.html">Baris Alat</a></li>\
    <li><a target="_top" href="id/text/scalc/main0202.html">Baris Pemformatan</a></li>\
    <li><a target="_top" href="id/text/scalc/main0203.html">Baris Properti Objek Menggambar</a></li>\
    <li><a target="_top" href="id/text/scalc/main0205.html">Baris Pemformatan Teks</a></li>\
    <li><a target="_top" href="id/text/scalc/main0206.html">Bilah Rumus</a></li>\
    <li><a target="_top" href="id/text/scalc/main0208.html">Bilah Status</a></li>\
    <li><a target="_top" href="id/text/scalc/main0210.html">Batang Pratinjau Cetak</a></li>\
    <li><a target="_top" href="id/text/scalc/main0214.html">Bilah Citra</a></li>\
    <li><a target="_top" href="id/text/scalc/main0218.html">Baris Perkakas</a></li>\
    <li><a target="_top" href="id/text/shared/main0201.html">Baris Standar</a></li>\
    <li><a target="_top" href="id/text/shared/main0212.html">Bilah Data Tabel</a></li>\
    <li><a target="_top" href="id/text/shared/main0213.html">Baris Navigasi Formulir</a></li>\
    <li><a target="_top" href="id/text/shared/main0214.html">Baris Desain Kuiri</a></li>\
    <li><a target="_top" href="id/text/shared/main0226.html">Bilah Alat Desain Formulir</a></li>\
			</ul></li>\
		</ul></li>\
    <li><input type="checkbox" id="0803"><label for="0803">Tipe-tipe Fungsi dan Operator</label><ul>\
    <li><a target="_top" href="id/text/scalc/01/04060000.html">Panduan Fungsi</a></li>\
    <li><a target="_top" href="id/text/scalc/01/04060100.html">Fungsi oleh Kategori</a></li>\
    <li><a target="_top" href="id/text/scalc/01/04060107.html">Fungsi Susunan</a></li>\
    <li><a target="_top" href="id/text/scalc/01/04060120.html">Fungsi</a></li>\
    <li><a target="_top" href="id/text/scalc/01/04060101.html">Fungsi Basis Data</a></li>\
    <li><a target="_top" href="id/text/scalc/01/04060102.html">Fungsi Tanggal & Waktu</a></li>\
    <li><a target="_top" href="id/text/scalc/01/04060103.html">Fungsi Finansial Bagian Satu</a></li>\
    <li><a target="_top" href="id/text/scalc/01/04060119.html">Fungsi Finansial Bagian Dua</a></li>\
    <li><a target="_top" href="id/text/scalc/01/04060118.html">Fungsi Finansial Bagian Tiga</a></li>\
    <li><a target="_top" href="id/text/scalc/01/04060104.html">Fungsi Informasi</a></li>\
    <li><a target="_top" href="id/text/scalc/01/04060105.html">Fungsi Logika</a></li>\
    <li><a target="_top" href="id/text/scalc/01/04060106.html">Fungsi Matematika</a></li>\
    <li><a target="_top" href="id/text/scalc/01/04060108.html">Fungsi Statistik</a></li>\
    <li><a target="_top" href="id/text/scalc/01/04060181.html">Fungsi Statistika Bagian Satu</a></li>\
    <li><a target="_top" href="id/text/scalc/01/04060182.html">Fungsi Statistika Bagian Dua</a></li>\
    <li><a target="_top" href="id/text/scalc/01/04060183.html">Fungsi Statistika Bagian Tiga</a></li>\
    <li><a target="_top" href="id/text/scalc/01/04060184.html">Fungsi Statistika Bagian Empat</a></li>\
    <li><a target="_top" href="id/text/scalc/01/04060185.html">Fungsi Statistika Bagian Lima</a></li>\
    <li><a target="_top" href="id/text/scalc/01/04060109.html">Fungsi Pengolah Angka</a></li>\
    <li><a target="_top" href="id/text/scalc/01/04060110.html">Fungsi Teks</a></li>\
    <li><a target="_top" href="id/text/scalc/01/04060111.html">Fungsi Tambahan</a></li>\
    <li><a target="_top" href="id/text/scalc/01/04060115.html">Add-in Functions, List of Analysis Functions Part One</a></li>\
    <li><a target="_top" href="id/text/scalc/01/04060116.html">Add-in Functions, List of Analysis Functions Part Two</a></li>\
    <li><a target="_top" href="id/text/scalc/01/04060199.html">Operator di LibreOffice Calc</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/userdefined_function.html">User-Defined Functions</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0804"><label for="0804">Memuat, Menyimpan, Mengimpor, dan Mengekspor</label><ul>\
    <li><a target="_top" href="id/text/scalc/guide/webquery.html">Inserting External Data in Table (WebQuery)</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/html_doc.html">Menyimpan dan Membuka Lembar Kerja dalam HTML</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/csv_formula.html">Mengimpor dan Mengekspor Dokumen</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0805"><label for="0805">Memformat</label><ul>\
    <li><a target="_top" href="id/text/scalc/guide/text_rotate.html">Rotating Text</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/text_wrap.html">Writing Multi-line Text</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/text_numbers.html">Formatting Numbers as Text</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/super_subscript.html">Text Superscript / Subscript</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/row_height.html">Changing Row Height or Column Width</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/cellstyle_conditional.html">Applying Conditional Formatting</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/cellstyle_minusvalue.html">Highlighting Negative Numbers</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/cellstyle_by_formula.html">Assigning Formats by Formula</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/integer_leading_zero.html">Entering a Number with Leading Zeros</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/format_table.html">Formatting Spreadsheets</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/format_value.html">Formatting Numbers With Decimals</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/value_with_name.html">Menamai Sel</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/table_rotate.html">Rotating Tables (Transposing)</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/rename_table.html">Renaming Sheets</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/year2000.html">19xx/20xx Years</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/rounding_numbers.html">Using Rounded Off Numbers</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/currency_format.html">Cells in Currency Format</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/autoformat.html">Menggunakan Format Otomatis pada Tabel</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/note_insert.html">Inserting and Editing Comments</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/design.html">Selecting Themes for Sheets</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/fraction_enter.html">Entering Fractions</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0806"><label for="0806">Menyaring dan Mengurut</label><ul>\
    <li><a target="_top" href="id/text/scalc/guide/filters.html">Applying Filters</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/specialfilter.html">Filter: Applying Advanced Filters</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/autofilter.html">Menerapkan Saring Otomatis</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/sorted_list.html">Applying Sort Lists</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0807"><label for="0807">Mencetak</label><ul>\
    <li><a target="_top" href="id/text/scalc/guide/print_title_row.html">Printing Rows or Columns on Every Page</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/print_landscape.html">Printing Sheets in Landscape Format</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/print_details.html">Printing Sheet Details</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/print_exact.html">Defining Number of Pages for Printing</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0808"><label for="0808">Jangkauan Data</label><ul>\
    <li><a target="_top" href="id/text/scalc/guide/database_define.html">Defining Database Ranges</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/database_filter.html">Filtering Cell Ranges</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/database_sort.html">Sorting Data</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0809"><label for="0809">Tabel Pivot</label><ul>\
    <li><a target="_top" href="id/text/scalc/guide/datapilot.html">Bagi Tabel</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/datapilot_createtable.html">Membuat Nama</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/datapilot_deletetable.html">Menghapus Isi</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/datapilot_edittable.html">Menyunting Tabel di dalam Teks</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/datapilot_filtertable.html">Penyaringan data</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/datapilot_tipps.html">Memilih Jangkauan Basis Data</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/datapilot_updatetable.html">Menyunting Tabel di dalam Teks</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="08091"><label for="08091">Bagan Pivot</label><ul>\
    <li><a target="_top" href="id/text/scalc/guide/pivotchart.html">Pivot Chart</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/pivotchart_create.html">Creating Pivot Charts</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/pivotchart_edit.html">Editing Pivot Charts</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/pivotchart_filter.html">Filtering Pivot Charts</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/pivotchart_update.html">Pivot Chart Update</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/pivotchart_delete.html">Deleting Pivot Charts</a></li>\
                </ul></li>\
    <li><input type="checkbox" id="0810"><label for="0810">Skenario</label><ul>\
    <li><a target="_top" href="id/text/scalc/guide/scenario.html">Using Scenarios</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0811"><label for="0811">Referensi</label><ul>\
    <li><a target="_top" href="id/text/scalc/guide/relativ_absolut_ref.html">Addresses and References, Absolute and Relative</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/cellreferences.html">Referencing a Cell in Another Document</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/cellreferences_url.html">References to Other Sheets and Referencing URLs</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/cellreference_dragdrop.html">Referencing Cells by Drag-and-Drop</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/address_auto.html">Mengenali Nama sebagai Pengalamatan</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0812"><label for="0812">Melihat, Memilh, Menggandakan</label><ul>\
    <li><a target="_top" href="id/text/scalc/guide/table_view.html">Changing Table Views</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/formula_value.html">Displaying Formulas or Values</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/line_fix.html">Freezing Rows or Columns as Headers</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/multi_tables.html">Navigating Through Sheets Tabs</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/edit_multitables.html">Menerapkan Banyak Operasi</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/cellcopy.html">Only Copy Visible Cells</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/mark_cells.html">Memilih Banyak Sel</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0813"><label for="0813">Rumus dan Kalkukasi</label><ul>\
    <li><a target="_top" href="id/text/scalc/guide/formulas.html">Calculating With Formulas</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/formula_copy.html">Copying Formulas</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/formula_enter.html">Entering Formulas</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/formula_value.html">Displaying Formulas or Values</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/calculate.html">Kalkulasi dalam Pengolah Angka</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/calc_date.html">Calculating With Dates and Times</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/calc_series.html">Automatically Calculating Series</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/calc_timevalues.html">Menghitung Perbedaan Waktu</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/matrixformula.html">Entering Matrix Formulas</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0814"><label for="0814">Perlindungan</label><ul>\
    <li><a target="_top" href="id/text/scalc/guide/cell_protect.html">Melindungi Sel dari Perubahan</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/cell_unprotect.html">Mencabut Proteksi terhadap Sel</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0815"><label for="0815">Lain-lain</label><ul>\
    <li><a target="_top" href="id/text/scalc/guide/auto_off.html">Deactivating Automatic Changes</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/consolidate.html">Consolidating Data</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/goalseek.html">Applying Goal Seek</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/multioperation.html">Menerapkan Banyak Operasi</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/multitables.html">Menerapkan Banyak Operasi</a></li>\
    <li><a target="_top" href="id/text/scalc/guide/validity.html">Validity of Cell Contents</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="05"><label for="05">Grafik dan Diagram</label><ul>\
    <li><input type="checkbox" id="0501"><label for="0501">Informasi Umum</label><ul>\
    <li><a target="_top" href="id/text/schart/main0000.html">Grafik dalam LibreOffice</a></li>\
    <li><a target="_top" href="id/text/schart/main0503.html">Fitur-fitur LibreOffice Diagram</a></li>\
    <li><a target="_top" href="id/text/schart/04/01020000.html">Shortcuts untuk Diagram</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="01"><label for="01">Pemasangan</label><ul>\
    <li><a target="_top" href="id/text/shared/guide/ms_doctypes.html">Changing the Association of Microsoft Office Document Types</a></li>\
    <li><a target="_top" href="id/text/shared/01/profile_safe_mode.html">Safe Mode</a></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="10"><label for="10">Topik Bantuan Umum</label><ul>\
    <li><input type="checkbox" id="1001"><label for="1001">Informasi Umum</label><ul>\
    <li><a target="_top" href="id/text/shared/main0400.html">Tombol Pintas</a></li>\
    <li><a target="_top" href="id/text/shared/00/00000005.html">Daftar Kata Umum</a></li>\
    <li><a target="_top" href="id/text/shared/00/00000002.html">Glossary of Internet Terms</a></li>\
    <li><a target="_top" href="id/text/shared/guide/accessibility.html">Aksesibilitas dalam LibreOffice</a></li>\
    <li><a target="_top" href="id/text/shared/guide/keyboard.html">Shortcuts (LibreOffice Accessibility)</a></li>\
    <li><a target="_top" href="id/text/shared/04/01010000.html">Tombol Pintas Umum dalam LibreOffice</a></li>\
    <li><a target="_top" href="id/text/shared/guide/version_number.html">Veris dan Nomor Bangun</a></li>\
</ul></li>\
    <li><input type="checkbox" id="1002"><label for="1002">LibreOffice dan Microsoft Office</label><ul>\
    <li><a target="_top" href="id/text/shared/guide/ms_user.html">Using Microsoft Office and LibreOffice</a></li>\
    <li><a target="_top" href="id/text/shared/guide/microsoft_terms.html">Comparing Microsoft Office and LibreOffice Terms</a></li>\
    <li><a target="_top" href="id/text/shared/guide/ms_import_export_limitations.html">About Converting Microsoft Office Documents</a></li>\
    <li><a target="_top" href="id/text/shared/guide/ms_doctypes.html">Changing the Association of Microsoft Office Document Types</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1004"><label for="1004">Opsi LibreOffice</label><ul>\
    <li><a target="_top" href="id/text/shared/optionen/01000000.html">Pilihan</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/01010100.html">Data Pengguna</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/01010200.html">Umum</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/01010300.html">Jalur</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/01010400.html">Bantuan Menulis</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/01010500.html">Color</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/01010600.html">Umum</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/01010700.html">Huruf</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/01010800.html">Tampilan</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/01010900.html">Pilihan Cetak</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/01012000.html">Application Colors</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/01013000.html">Aksesibilitas</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/java.html">Advanced</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/expertconfig.html">Expert Configuration</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/persona_firefox.html">Personalization</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/BasicIDE.html">Basic IDE</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/opencl.html">Open CL</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/01020000.html">Load/Save options</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/01030000.html">Internet options</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/01040000.html">Pilihan Dokumen Teks</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/01050000.html">Pilihan Dokumen HTML</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/01060000.html">Spreadsheet Options</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/01070000.html">Presentation Options</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/01080000.html">Drawing Options</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/01090000.html">Rumus</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/01110000.html">Chart options</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/01130100.html">Properti VBA</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/01130200.html">Microsoft Office</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/01140000.html">Bahasa</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/01150000.html">Language Setting Options</a></li>\
    <li><a target="_top" href="id/text/shared/optionen/01160000.html">Data sources options</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1005"><label for="1005">Wisaya</label><ul>\
    <li><a target="_top" href="id/text/shared/autopi/01000000.html">Panduan</a></li>\
    <li><input type="checkbox" id="100501"><label for="100501">Wisaya Surat</label><ul>\
    <li><a target="_top" href="id/text/shared/autopi/01010000.html">Panduan Surat</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100502"><label for="100502">Wisaya Faks</label><ul>\
    <li><a target="_top" href="id/text/shared/autopi/01020000.html">Panduan Faks</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100504"><label for="100504">Wisaya Agenda</label><ul>\
    <li><a target="_top" href="id/text/shared/autopi/01040000.html">Panduan Agenda</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100506"><label for="100506">Wisaya Ekspor HTML</label><ul>\
    <li><a target="_top" href="id/text/shared/autopi/01110000.html">Ekspor HTML</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100510"><label for="100510">Wisaya Pengonversi Dokumen</label><ul>\
    <li><a target="_top" href="id/text/shared/autopi/01130000.html">Konverter Dokumen</a></li>\
			</ul></li>\
    <li><a target="_top" href="id/text/shared/autopi/01150000.html">Panduan Konverter Euro</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1006"><label for="1006">Menata LibreOffice</label><ul>\
    <li><a target="_top" href="id/text/shared/guide/configure_overview.html">Configuring LibreOffice</a></li>\
    <li><a target="_top" href="id/text/shared/01/packagemanager.html">Extension Manager</a></li>\
    <li><a target="_top" href="id/text/shared/guide/flat_icons.html">Mengubah Tampilan Ikon</a></li>\
    <li><a target="_top" href="id/text/shared/guide/edit_symbolbar.html">Adding Buttons to Toolbars</a></li>\
    <li><a target="_top" href="id/text/shared/guide/workfolder.html">Mengubah Direktori Kerja Anda</a></li>\
    <li><a target="_top" href="id/text/shared/guide/standard_template.html">Changing Default Templates</a></li>\
    <li><a target="_top" href="id/text/shared/guide/data_addressbook.html">Registering an Address Book</a></li>\
    <li><a target="_top" href="id/text/shared/guide/formfields.html">Inserting and Editing Buttons</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1007"><label for="1007">Bekerja dengan Tampilan</label><ul>\
    <li><a target="_top" href="id/text/shared/guide/navigator_setcursor.html">Navigation to Quickly Reach Objects</a></li>\
    <li><a target="_top" href="id/text/shared/guide/navigator.html">Navigator for Document Overview</a></li>\
    <li><a target="_top" href="id/text/shared/guide/autohide.html">Showing, Docking and Hiding Windows</a></li>\
    <li><a target="_top" href="id/text/shared/guide/navpane_on.html">Showing Navigation Pane of the Help</a></li>\
    <li><a target="_top" href="id/text/shared/guide/textmode_change.html">Switching Between Insert Mode and Overwrite Mode</a></li>\
    <li><a target="_top" href="id/text/shared/guide/floating_toolbar.html">Using Toolbars</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="10071"><label for="10071">Tanda tangan Digital</label><ul>\
    <li><a target="_top" href="id/text/shared/guide/digital_signatures.html">About Digital Signatures</a></li>\
    <li><a target="_top" href="id/text/shared/guide/digitalsign_send.html">Applying Digital Signatures</a></li>\
    <li><a target="_top" href="id/text/shared/01/digitalsignaturespdf.html">Digital Signature in PDF Export</a></li>\
    <li><a target="_top" href="id/text/shared/01/signexistingpdf.html">Signing Existing PDF</a></li>\
    <li><a target="_top" href="id/text/swriter/01/addsignatureline.html">Adding Signature Line in Text Documents</a></li>\
    <li><a target="_top" href="id/text/swriter/01/signsignatureline.html">Signing the Signature Line</a></li>\
                </ul></li>\
    <li><input type="checkbox" id="1008"><label for="1008">Mencetak, Mengefaks, Mengirim</label><ul>\
    <li><a target="_top" href="id/text/shared/guide/labels_database.html">Printing Address Labels</a></li>\
    <li><a target="_top" href="id/text/shared/guide/print_blackwhite.html">Printing in Black and White</a></li>\
    <li><a target="_top" href="id/text/shared/guide/email.html">Sending Documents as E-mail</a></li>\
    <li><a target="_top" href="id/text/shared/guide/fax.html">Sending Faxes and Configuring LibreOffice for Faxing</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1009"><label for="1009">Seret & Jatuhkan</label><ul>\
    <li><a target="_top" href="id/text/shared/guide/dragdrop.html">Dragging and Dropping Within a LibreOffice Document</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/dragdroptext.html">Moving and Copying Text in Documents</a></li>\
    <li><a target="_top" href="id/text/shared/guide/dragdrop_table.html">Copying Spreadsheet Areas to Text Documents</a></li>\
    <li><a target="_top" href="id/text/shared/guide/dragdrop_graphic.html">Copying Graphics Between Documents</a></li>\
    <li><a target="_top" href="id/text/shared/guide/dragdrop_fromgallery.html">Copying Graphics From the Gallery</a></li>\
    <li><a target="_top" href="id/text/shared/guide/dragdrop_beamer.html">Drag-and-Drop With the Data Source View</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1010"><label for="1010">Salin dan Tempel</label><ul>\
    <li><a target="_top" href="id/text/shared/guide/copy_drawfunctions.html">Copying Drawing Objects Into Other Documents</a></li>\
    <li><a target="_top" href="id/text/shared/guide/dragdrop_graphic.html">Copying Graphics Between Documents</a></li>\
    <li><a target="_top" href="id/text/shared/guide/dragdrop_fromgallery.html">Copying Graphics From the Gallery</a></li>\
    <li><a target="_top" href="id/text/shared/guide/dragdrop_table.html">Copying Spreadsheet Areas to Text Documents</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1012"><label for="1012">Grafik dan Diagram</label><ul>\
    <li><a target="_top" href="id/text/shared/guide/chart_insert.html">Inserting Charts</a></li>\
    <li><a target="_top" href="id/text/schart/main0000.html">Grafik dalam LibreOffice</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1013"><label for="1013">Muat, Simpan, Impor, Ekspor</label><ul>\
    <li><a target="_top" href="id/text/shared/guide/doc_open.html">Opening Documents</a></li>\
    <li><a target="_top" href="id/text/shared/guide/import_ms.html">Opening documents saved in other formats</a></li>\
    <li><a target="_top" href="id/text/shared/guide/doc_save.html">Saving Documents</a></li>\
    <li><a target="_top" href="id/text/shared/guide/doc_autosave.html">Saving Documents Automatically</a></li>\
    <li><a target="_top" href="id/text/shared/guide/export_ms.html">Saving Documents in Other Formats</a></li>\
    <li><a target="_top" href="id/text/shared/guide/data_dbase2office.html">Importing and Exporting Data in Text Format</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1014"><label for="1014">Taut dan Referensi</label><ul>\
    <li><a target="_top" href="id/text/shared/guide/hyperlink_insert.html">Inserting Hyperlinks</a></li>\
    <li><a target="_top" href="id/text/shared/guide/hyperlink_rel_abs.html">Relative and Absolute Links</a></li>\
    <li><a target="_top" href="id/text/shared/guide/hyperlink_edit.html">Menyunting Taut</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1015"><label for="1015">Pelacakan Versi Dokumen</label><ul>\
    <li><a target="_top" href="id/text/shared/guide/redlining_doccompare.html">Comparing Versions of a Document</a></li>\
    <li><a target="_top" href="id/text/shared/guide/redlining_docmerge.html">Merging Versions</a></li>\
    <li><a target="_top" href="id/text/shared/guide/redlining_enter.html">Recording Changes</a></li>\
    <li><a target="_top" href="id/text/shared/guide/redlining.html">Recording and Displaying Changes</a></li>\
    <li><a target="_top" href="id/text/shared/guide/redlining_accept.html">Accepting or Rejecting Changes</a></li>\
    <li><a target="_top" href="id/text/shared/guide/redlining_versions.html">Version Management</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1016"><label for="1016">Label dan Kartu Nama</label><ul>\
    <li><a target="_top" href="id/text/shared/guide/labels.html">Creating and Printing Labels and Business Cards</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1018"><label for="1018">Menyisipkan Data Eksternal</label><ul>\
    <li><a target="_top" href="id/text/shared/guide/copytable2application.html">Inserting Data From Spreadsheets</a></li>\
    <li><a target="_top" href="id/text/shared/guide/copytext2application.html">Inserting Data From Text Documents</a></li>\
    <li><a target="_top" href="id/text/shared/guide/insert_bitmap.html">Inserting, Editing, Saving Bitmaps</a></li>\
    <li><a target="_top" href="id/text/shared/guide/dragdrop_gallery.html">Adding Graphics to the Gallery</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1019"><label for="1019">Fungsi Otomatis</label><ul>\
    <li><a target="_top" href="id/text/shared/guide/autocorr_url.html">Mematikan Pengenalan URL Otomatis</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1020"><label for="1020">Mencari dan Mengganti</label><ul>\
    <li><a target="_top" href="id/text/shared/guide/data_search2.html">Searching With a Form Filter</a></li>\
    <li><a target="_top" href="id/text/shared/guide/data_search.html">Searching Tables and Form Documents</a></li>\
    <li><a target="_top" href="id/text/shared/01/02100001.html">List of Regular Expressions</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1021"><label for="1021">Panduan</label><ul>\
    <li><a target="_top" href="id/text/shared/guide/linestyles.html">Applying Line Styles</a></li>\
    <li><a target="_top" href="id/text/shared/guide/text_color.html">Mengubah Warna Teks.</a></li>\
    <li><a target="_top" href="id/text/shared/guide/change_title.html">Mengubah Judul Dokumen</a></li>\
    <li><a target="_top" href="id/text/shared/guide/round_corner.html">Creating Round Corners</a></li>\
    <li><a target="_top" href="id/text/shared/guide/background.html">Menentukan Warna atau Gambar Latar Belakang</a></li>\
    <li><a target="_top" href="id/text/shared/guide/lineend_define.html">Defining Line Ends</a></li>\
    <li><a target="_top" href="id/text/shared/guide/linestyle_define.html">Defining Line Styles</a></li>\
    <li><a target="_top" href="id/text/shared/guide/insert_graphic_drawit.html">Editing Graphic Objects</a></li>\
    <li><a target="_top" href="id/text/shared/guide/line_intext.html">Drawing Lines in Text</a></li>\
    <li><a target="_top" href="id/text/shared/guide/aaa_start.html">Langkah Pertama</a></li>\
    <li><a target="_top" href="id/text/shared/guide/gallery_insert.html">Inserting Objects From the Gallery</a></li>\
    <li><a target="_top" href="id/text/shared/guide/space_hyphen.html">Inserting Non-breaking Spaces, Hyphens and Soft Hyphens</a></li>\
    <li><a target="_top" href="id/text/shared/guide/insert_specialchar.html">Inserting Special Characters</a></li>\
    <li><a target="_top" href="id/text/shared/guide/tabs.html">Inserting and Editing Tab Stops</a></li>\
    <li><a target="_top" href="id/text/shared/guide/protection.html">Protecting Content in LibreOffice</a></li>\
    <li><a target="_top" href="id/text/shared/guide/redlining_protect.html">Protecting Records</a></li>\
    <li><a target="_top" href="id/text/shared/guide/pageformat_max.html">Selecting the Maximum Printable Area on a Page</a></li>\
    <li><a target="_top" href="id/text/shared/guide/measurement_units.html">Selecting Measurement Units</a></li>\
    <li><a target="_top" href="id/text/shared/guide/language_select.html">Selecting the Document Language</a></li>\
    <li><a target="_top" href="id/text/shared/guide/data_tabledefine.html">Table Design</a></li>\
    <li><a target="_top" href="id/text/shared/guide/numbering_stop.html">Turning off Bullets and Numbering for Individual Paragraphs</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="09"><label for="09">Fungsionalitas Basis Data</label><ul>\
    <li><input type="checkbox" id="0901"><label for="0901">Informasi Umum</label><ul>\
    <li><a target="_top" href="id/text/shared/explorer/database/main.html">LibreOffice Database</a></li>\
    <li><a target="_top" href="id/text/shared/guide/database_main.html">Database Overview</a></li>\
    <li><a target="_top" href="id/text/shared/guide/data_new.html">Creating a New Database</a></li>\
    <li><a target="_top" href="id/text/shared/guide/data_tables.html">Working with Tables</a></li>\
    <li><a target="_top" href="id/text/shared/guide/data_queries.html">Working with Queries</a></li>\
    <li><a target="_top" href="id/text/shared/guide/data_forms.html">Working with Forms</a></li>\
    <li><a target="_top" href="id/text/shared/guide/data_reports.html">Creating Reports</a></li>\
    <li><a target="_top" href="id/text/shared/guide/data_register.html">Registering and Deleting a Database</a></li>\
    <li><a target="_top" href="id/text/shared/guide/data_im_export.html">Importing and Exporting Data in Base</a></li>\
    <li><a target="_top" href="id/text/shared/guide/data_enter_sql.html">Executing SQL Commands</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="04"><label for="04">Presentasi dan Menggambar</label><ul>\
    <li><input type="checkbox" id="0401"><label for="0401">Informasi Umum dan Penggunaan Antar Muka Pengguna</label><ul>\
    <li><a target="_top" href="id/text/simpress/main0000.html">Selamat datang di Bantuan LibreOffice Impress</a></li>\
    <li><a target="_top" href="id/text/sdraw/main0000.html">Selamat datang di Bantuan LibreOffice Draw</a></li>\
    <li><a target="_top" href="id/text/simpress/main0503.html">Fitur LibreOffice Impress</a></li>\
    <li><a target="_top" href="id/text/sdraw/main0503.html">Fitur LibreOffice Draw</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/keyboard.html">Menggunakan Tombol Pintas di LibreOffice Impress</a></li>\
    <li><a target="_top" href="id/text/sdraw/guide/keyboard.html">Tombol Pintas untuk Objek Menggambar</a></li>\
    <li><a target="_top" href="id/text/simpress/04/01020000.html">Tombol Pintas untuk LibreOffice Impress</a></li>\
    <li><a target="_top" href="id/text/simpress/04/presenter.html">Pintasan Papan Ketik Konsol Penyaji</a></li>\
    <li><a target="_top" href="id/text/sdraw/04/01020000.html">Tombol Pintas untuk Menggambar</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/main.html">Instruksi bagi Penggunaan LibreOffice Impress</a></li>\
    <li><a target="_top" href="id/text/sdraw/guide/main.html">Instruksi untuk Menggunakan LibreOffice Draw</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0402"><label for="0402">Rujukan Menu dan Perintah</label><ul>\
    <li><input type="checkbox" id="040201"><label for="040201">Presentasi (LibreOffice Impress)</label><ul>\
    <li><input type="checkbox" id="04020101"><label for="04020101">Menu</label><ul>\
    <li><a target="_top" href="id/text/simpress/main0100.html">Menu</a></li>\
    <li><a target="_top" href="id/text/simpress/main0101.html">Berkas</a></li>\
    <li><a target="_top" href="id/text/simpress/main0102.html">Sunting</a></li>\
    <li><a target="_top" href="id/text/simpress/main0103.html">Tampilan</a></li>\
    <li><a target="_top" href="id/text/simpress/main0104.html">Sisip</a></li>\
    <li><a target="_top" href="id/text/simpress/main0105.html">Format</a></li>\
    <li><a target="_top" href="id/text/simpress/main0117.html">Salindia</a></li>\
    <li><a target="_top" href="id/text/simpress/main0114.html">Pertunjukan Salindia</a></li>\
    <li><a target="_top" href="id/text/simpress/main0106.html">Perkakas</a></li>\
    <li><a target="_top" href="id/text/simpress/main0107.html">Jendela</a></li>\
    <li><a target="_top" href="id/text/shared/main0108.html">Bantuan</a></li>\
                 </ul></li>\
    <li><input type="checkbox" id="04020102"><label for="04020102">Bilah alat</label><ul>\
    <li><a target="_top" href="id/text/simpress/main0200.html">Baris Alat</a></li>\
    <li><a target="_top" href="id/text/simpress/main0202.html">Baris Garis dan Pengisian</a></li>\
    <li><a target="_top" href="id/text/simpress/main0203.html">Baris Pemformatan Teks</a></li>\
    <li><a target="_top" href="id/text/simpress/main0204.html">Baris Tampilan Salindia</a></li>\
    <li><a target="_top" href="id/text/simpress/main0206.html">Bilah Status</a></li>\
    <li><a target="_top" href="id/text/simpress/main0209.html">Penggaris</a></li>\
    <li><a target="_top" href="id/text/simpress/main0210.html">Bilah Menggambar</a></li>\
    <li><a target="_top" href="id/text/simpress/main0211.html">Baris Kerangka</a></li>\
    <li><a target="_top" href="id/text/simpress/main0212.html">Baris Penyusun Salindia</a></li>\
    <li><a target="_top" href="id/text/simpress/main0213.html">Baris Opsi</a></li>\
    <li><a target="_top" href="id/text/simpress/main0214.html">Bilah Citra</a></li>\
    <li><a target="_top" href="id/text/shared/main0201.html">Baris Standar</a></li>\
    <li><a target="_top" href="id/text/shared/main0213.html">Baris Navigasi Formulir</a></li>\
    <li><a target="_top" href="id/text/shared/main0226.html">Bilah Alat Desain Formulir</a></li>\
    <li><a target="_top" href="id/text/shared/main0227.html">Baris Sunting Titik</a></li>\
                 </ul></li>\
             </ul></li>\
    <li><input type="checkbox" id="040202"><label for="040202">Gambar (LibreOffice Draw)</label><ul>\
    <li><input type="checkbox" id="04020201"><label for="04020201">Menu</label><ul>\
    <li><a target="_top" href="id/text/sdraw/main0100.html">Menu</a></li>\
    <li><a target="_top" href="id/text/sdraw/main0101.html">Berkas</a></li>\
    <li><a target="_top" href="id/text/sdraw/main0102.html">Sunting</a></li>\
    <li><a target="_top" href="id/text/sdraw/main0103.html">Tampilan</a></li>\
    <li><a target="_top" href="id/text/sdraw/main0104.html">Sisip</a></li>\
    <li><a target="_top" href="id/text/sdraw/main0105.html">Format</a></li>\
    <li><a target="_top" href="id/text/sdraw/main0106.html">Perkakas</a></li>\
    <li><a target="_top" href="id/text/simpress/main0113.html">Ubah</a></li>\
    <li><a target="_top" href="id/text/simpress/main0107.html">Jendela</a></li>\
    <li><a target="_top" href="id/text/shared/main0108.html">Bantuan</a></li>\
                 </ul></li>\
    <li><input type="checkbox" id="04020202"><label for="04020202">Bilah alat</label><ul>\
    <li><a target="_top" href="id/text/sdraw/main0200.html">Baris Alat</a></li>\
    <li><a target="_top" href="id/text/sdraw/main0210.html">Baris Menggambar</a></li>\
    <li><a target="_top" href="id/text/sdraw/main0213.html">Baris Opsi</a></li>\
    <li><a target="_top" href="id/text/shared/main0201.html">Baris Standar</a></li>\
    <li><a target="_top" href="id/text/shared/main0213.html">Baris Navigasi Formulir</a></li>\
    <li><a target="_top" href="id/text/shared/main0226.html">Bilah Alat Desain Formulir</a></li>\
    <li><a target="_top" href="id/text/shared/main0227.html">Baris Sunting Titik</a></li>\
                 </ul></li>\
             </ul></li>\
         </ul></li>\
    <li><input type="checkbox" id="0403"><label for="0403">Memuat, Menyimpan, Mengimpor, dan Mengekspor</label><ul>\
    <li><a target="_top" href="id/text/simpress/guide/html_export.html">Menyimpan Presentasi dalam Bentuk HTML</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/html_import.html">Mengimpor Halaman HTML ke Bentuk Presentasi</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/palette_files.html">Memuat Daftar Arsir, Gradien, dan Warna</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/animated_gif_save.html">Mengekspor Animasi dalam Bentuk GIF</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/table_insert.html">Mengikutkan Lembar Kerja dalam Salindia</a></li>\
    <li><a target="_top" href="id/text/sdraw/guide/graphic_insert.html">Menyisipkan Grafis</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/page_copy.html">Menyalin Salindia Dari Presentasi Lain</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0404"><label for="0404">Memformat</label><ul>\
    <li><a target="_top" href="id/text/simpress/guide/palette_files.html">Memuat Daftar Arsir, Gradien, dan Warna</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/line_arrow_styles.html">Memuat Gaya Garis dan Panah</a></li>\
    <li><a target="_top" href="id/text/sdraw/guide/color_define.html">Menentukan Warna Ubahan</a></li>\
    <li><a target="_top" href="id/text/sdraw/guide/gradient.html">Membuat Isi Bergradien</a></li>\
    <li><a target="_top" href="id/text/sdraw/guide/eyedropper.html">Menggantikan Warna</a></li>\
    <li><a target="_top" href="id/text/sdraw/guide/align_arrange.html">Menyusun, Meratakan, dan Mendistribusikan Objek</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/background.html">Mengubah Isi Latar Belakang Salindia</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/footer.html">Menambahkan Kepala atau Kaki pada Semua Salindia</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/masterpage.html">Applying a Slide Design to a Master Slide</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/move_object.html">Memindahkan Objek</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0405"><label for="0405">Mencetak</label><ul>\
    <li><a target="_top" href="id/text/simpress/guide/printing.html">Mencetak Presentasi</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/print_tofit.html">Mencetak Salindia Agar Pas Ukuran Kertas</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0406"><label for="0406">Efek</label><ul>\
    <li><a target="_top" href="id/text/simpress/guide/animated_gif_save.html">Mengekspor Animasi dalam Bentuk GIF</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/animated_objects.html">Menganimasikan Objek dalam Salindia Presentasi</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/animated_slidechange.html">Menganimasikan Transisi Salindia</a></li>\
    <li><a target="_top" href="id/text/sdraw/guide/cross_fading.html">Pudar-Silang Dua Objek</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/animated_gif_create.html">Membuat Citra GIF Bergerak</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0407"><label for="0407">Objek, Grafik, dan Bitmap</label><ul>\
    <li><a target="_top" href="id/text/sdraw/guide/combine_etc.html">Menggabungkan Objek dan Membangun Bentuk</a></li>\
    <li><a target="_top" href="id/text/sdraw/guide/draw_sector.html">Menggambar Sektor dan Segmen</a></li>\
    <li><a target="_top" href="id/text/sdraw/guide/duplicate_object.html">Menggandakan Objek</a></li>\
    <li><a target="_top" href="id/text/sdraw/guide/rotate_object.html">Memutar Objek</a></li>\
    <li><a target="_top" href="id/text/sdraw/guide/join_objects3d.html">Merakit Objek 3D</a></li>\
    <li><a target="_top" href="id/text/sdraw/guide/join_objects.html">Menghubungkan Garis</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/text2curve.html">Mengonversi Karakter Teks ke dalam Objek Menggambar</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/vectorize.html">Mengonversi Citra Bitmap ke dalam Grafik Vektor</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/3d_create.html">Mengonversi Objek 2D ke Kurva, Poligon, dan Objek 3D</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/line_arrow_styles.html">Memuat Gaya Garis dan Panah</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/line_draw.html">Menggambar Kurva</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/line_edit.html">Menyunting Kurva</a></li>\
    <li><a target="_top" href="id/text/sdraw/guide/graphic_insert.html">Menyisipkan Grafis</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/table_insert.html">Mengikutkan Lembar Kerja dalam Salindia</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/move_object.html">Memindahkan Objek</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/select_object.html">Memilih Objek Yang Mendasari</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/orgchart.html">Membuat Bagan Alur</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0408"><label for="0408">Grup dan layer</label><ul>\
    <li><a target="_top" href="id/text/sdraw/guide/groups.html">Mengelompokkan Objek</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/layers.html">Tentang Lapisan</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/layer_new.html">Menyisipkan Lapisan.</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/layer_tipps.html">Bekerja dengan Lapisan</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/layer_move.html">Memindahkan Objek ke Lapisan Berbeda</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0409"><label for="0409">Teks pada Presentasi dan Menggambar</label><ul>\
    <li><a target="_top" href="id/text/sdraw/guide/text_enter.html">Menambahkan Teks</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/text2curve.html">Mengonversi Karakter Teks ke dalam Objek Menggambar</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0410"><label for="0410">Menampilkan</label><ul>\
    <li><a target="_top" href="id/text/simpress/guide/arrange_slides.html">Mengubah Urutan Salindia</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/change_scale.html">Mengubah Tampilan dengan Tombol Kibor</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0411"><label for="0411">Pertunjukan Salindia</label><ul>\
    <li><a target="_top" href="id/text/simpress/guide/show.html">Menampilkan suatu Pertunjukan Salindia</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/presenter_console.html">Using the Presenter Console</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/impress_remote.html">Impress Remote Guide</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/individual.html">Membuat Pertunjukan Salindia Ubahan</a></li>\
    <li><a target="_top" href="id/text/simpress/guide/rehearse_timings.html">Berlatih Mengatur Waktu Perubahan Salindia</a></li>\
         </ul></li>\
     </ul></li></ul>\
    <ul><li><input type="checkbox" id="03"><label for="03">Rumus</label><ul>\
    <li><input type="checkbox" id="0301"><label for="0301">Informasi Umum dan Penggunaan Antar Muka Pengguna</label><ul>\
    <li><a target="_top" href="id/text/smath/main0000.html">Selamat datang di Bantuan LibreOffice Math</a></li>\
    <li><a target="_top" href="id/text/smath/main0503.html">Fitur LibreOffice Math</a></li>\
    <li><a target="_top" href="id/text/smath/guide/main.html">Petunjuk Menggunakan LibreOffice Math</a></li>\
    <li><a target="_top" href="id/text/smath/guide/keyboard.html">Tombol Pintas (Aksesibilitas LibreOffice Math)</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0302"><label for="0302">Rujukan Menu dan Perintah</label><ul>\
    <li><a target="_top" href="id/text/smath/main0100.html">Menu</a></li>\
    <li><a target="_top" href="id/text/smath/main0200.html">Baris Alat</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0303"><label for="0303">Bekerja dengan Rumus</label><ul>\
    <li><a target="_top" href="id/text/smath/guide/align.html">Meratakan Bagian-bagian Rumus secara Manual</a></li>\
    <li><a target="_top" href="id/text/smath/guide/attributes.html">Mengubah Atribut Baku</a></li>\
    <li><a target="_top" href="id/text/smath/guide/brackets.html">Menggabungkan Bagian-bagian Rumus di dalam Tanda Kurung</a></li>\
    <li><a target="_top" href="id/text/smath/guide/comment.html">Menambahkan Komentar</a></li>\
    <li><a target="_top" href="id/text/smath/guide/newline.html">Memasukkan Pemutus Baris</a></li>\
    <li><a target="_top" href="id/text/smath/guide/parentheses.html">Memasukkan Tanda Kurung</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="02"><label for="02">Dokumen Teks</label><ul>\
    <li><input type="checkbox" id="0201"><label for="0201">Informasi Umum dan Penggunaan Antar Muka Pengguna</label><ul>\
    <li><a target="_top" href="id/text/swriter/main0000.html">Selamat datang di Bantuan LibreOffice Writer</a></li>\
    <li><a target="_top" href="id/text/swriter/main0503.html">Fitur LibreOffice Writer</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/main.html">Instruksi untuk Menggunakan LibreOffice Writer</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/resize_navigator.html">Docking and Resizing Windows</a></li>\
    <li><a target="_top" href="id/text/swriter/04/01020000.html">Tombol Pintas untuk LibreOffice Writer</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/words_count.html">Counting Words</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/keyboard.html">Using Shortcut Keys (LibreOffice Writer Accessibility)</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0202"><label for="0202">Rujukan Menu dan Perintah</label><ul>\
    <li><input type="checkbox" id="020201"><label for="020201">Menu</label><ul>\
    <li><a target="_top" href="id/text/swriter/main0100.html">Menu</a></li>\
    <li><a target="_top" href="id/text/swriter/main0101.html">Berkas</a></li>\
    <li><a target="_top" href="id/text/swriter/main0102.html">Sunting</a></li>\
    <li><a target="_top" href="id/text/swriter/main0103.html">Tampilan</a></li>\
    <li><a target="_top" href="id/text/swriter/main0104.html">Sisip</a></li>\
    <li><a target="_top" href="id/text/swriter/main0105.html">Format</a></li>\
    <li><a target="_top" href="id/text/swriter/main0115.html">Gaya</a></li>\
    <li><a target="_top" href="id/text/swriter/main0110.html">Tabel</a></li>\
    <li><a target="_top" href="id/text/swriter/main0120.html">Form Menu</a></li>\
    <li><a target="_top" href="id/text/swriter/main0106.html">Perkakas</a></li>\
    <li><a target="_top" href="id/text/swriter/main0107.html">Jendela</a></li>\
    <li><a target="_top" href="id/text/shared/main0108.html">Bantuan</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="020202"><label for="020202">Bilah alat</label><ul>\
    <li><a target="_top" href="id/text/swriter/main0200.html">Baris Alat</a></li>\
    <li><a target="_top" href="id/text/swriter/main0202.html">Bilah Pemformatan</a></li>\
    <li><a target="_top" href="id/text/swriter/main0203.html">Bilah Citra</a></li>\
    <li><a target="_top" href="id/text/swriter/main0204.html">Baris Tabel</a></li>\
    <li><a target="_top" href="id/text/swriter/main0205.html">Baris Properti Objek Menggambar</a></li>\
    <li><a target="_top" href="id/text/swriter/main0206.html">Baris Bulatan dan Penomoran</a></li>\
    <li><a target="_top" href="id/text/swriter/main0208.html">Bilah Status</a></li>\
    <li><a target="_top" href="id/text/swriter/main0210.html">Pratinjau Cetak</a></li>\
    <li><a target="_top" href="id/text/swriter/main0213.html">Penggaris</a></li>\
    <li><a target="_top" href="id/text/swriter/main0214.html">Bilah Rumus</a></li>\
    <li><a target="_top" href="id/text/swriter/main0215.html">Baris Bingkai</a></li>\
    <li><a target="_top" href="id/text/swriter/main0216.html">Baris Objek OLE</a></li>\
    <li><a target="_top" href="id/text/swriter/main0220.html">Baris Objek Teks</a></li>\
    <li><a target="_top" href="id/text/shared/main0201.html">Baris Standar</a></li>\
    <li><a target="_top" href="id/text/shared/main0212.html">Bilah Data Tabel</a></li>\
    <li><a target="_top" href="id/text/shared/main0213.html">Baris Navigasi Formulir</a></li>\
    <li><a target="_top" href="id/text/shared/main0214.html">Baris Desain Kuiri</a></li>\
    <li><a target="_top" href="id/text/shared/main0226.html">Bilah Alat Desain Formulir</a></li>\
    <li><a target="_top" href="id/text/swriter/librelogo/LibreLogo.html">Bilah Alat LibreLogo</a></li>\
			</ul></li>\
		</ul></li>\
    <li><input type="checkbox" id="0203"><label for="0203">Membuat Dokumen Teks</label><ul>\
    <li><a target="_top" href="id/text/swriter/guide/text_nav_keyb.html">Navigating and Selecting With the Keyboard</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/text_direct_cursor.html">Using the Direct Cursor</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0204"><label for="0204">Grafik dalam Dokumen Teks</label><ul>\
    <li><a target="_top" href="id/text/swriter/guide/insert_graphic.html">Menyisipkan Grafis</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/insert_graphic_dialog.html">Menyisipkan Grafis dari Berkas</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/insert_graphic_gallery.html">Inserting Graphics From the Gallery With Drag-and-Drop</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/insert_graphic_scan.html">Menyisipkan Citra Hasil Pindaian</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/insert_graphic_fromchart.html">Inserting a Calc Chart into a Text Document</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/insert_graphic_fromdraw.html">Inserting Graphics From LibreOffice Draw or Impress</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0205"><label for="0205">Tabel dalam Dokumen Teks</label><ul>\
    <li><a target="_top" href="id/text/swriter/guide/number_date_conv.html">Turning Number Recognition On or Off in Tables</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/tablemode.html">Modifying Rows and Columns by Keyboard</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/table_delete.html">Deleting Tables or the Contents of a Table</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/table_insert.html">Menyisipkan Tabel</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/table_repeat_multiple_headers.html">Repeating a Table Header on a New Page</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/table_sizing.html">Resizing Rows and Columns in a Text Table</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/table_cells.html">Adding or Deleting a Row or Column to a Table Using the Keyboard</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0206"><label for="0206">Objek dalam Dokumen Teks</label><ul>\
    <li><a target="_top" href="id/text/swriter/guide/anchor_object.html">Memposisikan Objek</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/wrap.html">Wrapping Text Around Objects</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0207"><label for="0207">Seksi dan Kerangka dalam Dokumen Teks</label><ul>\
    <li><a target="_top" href="id/text/swriter/guide/sections.html">Menyunting Seksi</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/text_frame.html">Inserting, Editing, and Linking Text Frames</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/section_edit.html">Menyunting Seksi</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/section_insert.html">Inserting Sections</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0208"><label for="0208">Daftar Isi dan Indeks</label><ul>\
    <li><a target="_top" href="id/text/swriter/guide/chapter_numbering.html">Chapter Numbering</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/indices_userdef.html">User-Defined Indexes</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/indices_toc.html">Membuat Daftar Isi</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/indices_index.html">Creating Alphabetical Indexes</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/indices_multidoc.html">Indexes Covering Several Documents</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/indices_literature.html">Membuat Bibliografi</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/indices_delete.html">Editing or Deleting Index and Table Entries</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/indices_edit.html">Updating, Editing and Deleting Indexes and Tables of Contents</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/indices_enter.html">Defining Index or Table of Contents Entries</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/indices_form.html">Formatting an Index or a Table of Contents</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0209"><label for="0209">Ruas dalam Dokumen Teks</label><ul>\
    <li><a target="_top" href="id/text/swriter/guide/fields.html">About Fields</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/fields_date.html">Inserting a Fixed or Variable Date Field</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/field_convert.html">Converting a Field into Text</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0210"><label for="0210">Menavigasi Dokumen Teks</label><ul>\
    <li><a target="_top" href="id/text/swriter/guide/dragdroptext.html">Moving and Copying Text in Documents</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/arrange_chapters.html">Menyusun Ulang Dokumen dengan Memakai Navigator</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/hyperlinks.html">Inserting Hyperlinks With the Navigator</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/navigator.html">Navigator untuk Dokumen Teks</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0211"><label for="0211">Menghitung dalam Dokumen Teks</label><ul>\
    <li><a target="_top" href="id/text/swriter/guide/calculate_multitable.html">Menghitung Lintas Tabel</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/calculate.html">Menghitung dalam Dokumen Teks</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/calculate_clipboard.html">Menghitung dan Menempelkan Hasil dari suatu Rumus dalam sebuah Dokumen Teks</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/calculate_intable.html">Menghitung Total Sel dalam Tabel</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/calculate_intext.html">Menghitung Rumus Rumit dalam Dokumen Teks</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/calculate_intext2.html">Menampilkan Hasil dari Perhitungan Tabel dalam Tabel Lain</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0212"><label for="0212">Memformat Dokumen Teks</label><ul>\
    <li><input type="checkbox" id="021201"><label for="021201">Templat dan Gaya</label><ul>\
    <li><a target="_top" href="id/text/swriter/guide/templates_styles.html">Templat dan Gaya</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/even_odd_sdw.html">Alternating Page Styles on Odd and Even Pages</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/change_header.html">Creating a Page Style Based on the Current Page</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/load_styles.html">Using Styles From Another Document or Template</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/stylist_fromselect.html">Creating New Styles From Selections</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/stylist_update.html">Updating Styles From Selections</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/template_create.html">Creating a Document Template</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/template_default.html">Changing the Default Template</a></li>\
			</ul></li>\
    <li><a target="_top" href="id/text/swriter/guide/pageorientation.html">Changing Page Orientation (Landscape or Portrait)</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/text_capital.html">Changing the Case of Text</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/hidden_text.html">Hiding Text</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/header_pagestyles.html">Defining Different Headers and Footers</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/header_with_chapter.html">Inserting a Chapter Name and Number in a Header or a Footer</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/shortcut_writing.html">Applying Text Formatting While You Type</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/reset_format.html">Resetting Font Attributes</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/stylist_fillformat.html">Applying Styles in Fill Format Mode</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/wrap.html">Wrapping Text Around Objects</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/text_centervert.html">Using a Frame to Center Text on a Page</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/text_emphasize.html">Emphasizing Text</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/text_rotate.html">Rotating Text</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/page_break.html">Inserting and Deleting Page Breaks</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/pagestyles.html">Creating and Applying Page Styles</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/subscript.html">Making Text Superscript or Subscript</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0213"><label for="0213">Elemen Teks Spesial</label><ul>\
    <li><a target="_top" href="id/text/swriter/guide/captions.html">Menyunting Seksi</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/conditional_text.html">Conditional Text</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/conditional_text2.html">Conditional Text for Page Counts</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/fields_date.html">Inserting a Fixed or Variable Date Field</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/fields_enter.html">Menambahkan Ruas Masukan</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/footer_nextpage.html">Inserting Page Numbers of Continuation Pages</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/footer_pagenumber.html">Inserting Page Numbers in Footers</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/hidden_text.html">Hiding Text</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/header_pagestyles.html">Defining Different Headers and Footers</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/header_with_chapter.html">Inserting a Chapter Name and Number in a Header or a Footer</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/fields_userdata.html">Querying User Data in Fields or Conditions</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/footnote_usage.html">Inserting and Editing Footnotes or Endnotes</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/footnote_with_line.html">Spacing Between Footnotes</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/header_footer.html">About Headers and Footers</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/header_with_line.html">Formatting Headers or Footers</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/text_animation.html">Animating Text</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/form_letters_main.html">Creating a Form Letter</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0214"><label for="0214">Fungsi Otomatis</label><ul>\
    <li><a target="_top" href="id/text/swriter/guide/autocorr_except.html">Menambahkan Pengecualian ke Daftar OtoKoreksi</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/autotext.html">Menggunakan Teks Otomatis</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/auto_numbering.html">Untuk Membuat Penomoran atau Daftar Berbulatan Sembari Mengetik</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/auto_off.html">Mematikan OtoKoreksi</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/auto_spellcheck.html">Otomatis Memeriksa Ejaan</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/number_date_conv.html">Turning Number Recognition On or Off in Tables</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/using_hyphen.html">Pemenggalan Kata</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0215"><label for="0215">Penomoran dan Daftar</label><ul>\
    <li><a target="_top" href="id/text/swriter/guide/captions_numbers.html">Menambahkan Nomor Bab ke Kapsi</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/auto_numbering.html">Untuk Membuat Penomoran atau Daftar Berbulatan Sembari Mengetik</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/chapter_numbering.html">Chapter Numbering</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/insert_tab_innumbering.html">Changing the Outline Level of Numbered and Bulleted Lists</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/join_numbered_lists.html">Combining Numbered Lists</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/numbering_lines.html">Adding Line Numbers</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/numbering_paras.html">Modifying Numbering in a Numbered List</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/number_sequence.html">Defining Number Ranges</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/using_numbered_lists2.html">Adding Numbering</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/using_numbering.html">Numbering and Numbering Styles</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/using_numbered_lists.html">Adding Bullets</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0216"><label for="0216">Pemeriksaan Ejaan, Tesaurus, dan Bahasa</label><ul>\
    <li><a target="_top" href="id/text/swriter/guide/auto_spellcheck.html">Otomatis Memeriksa Ejaan</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/delete_from_dict.html">Removing Words From a User-Defined Dictionary</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/using_thesaurus.html">Thesaurus</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/spellcheck_dialog.html">Checking Spelling and Grammar</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0218"><label for="0218">Tips Penelusuran Masalah</label><ul>\
    <li><a target="_top" href="id/text/swriter/guide/insert_beforetable.html">Inserting Text Before a Table at the Top of Page</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/jump2statusbar.html">Going to Specific Bookmark</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0219"><label for="0219">Memuat, Menyimpan, Mengimpor, dan Mengekspor</label><ul>\
    <li><a target="_top" href="id/text/swriter/guide/send2html.html">Menyimpan Dokumen Teks dalam Format HTML</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/textdoc_inframe.html">Inserting an Entire Text Document</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0220"><label for="0220">Dokumen Induk</label><ul>\
    <li><a target="_top" href="id/text/swriter/guide/globaldoc.html">Master Documents and Subdocuments</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0221"><label for="0221">Taut dan Rererensi</label><ul>\
    <li><a target="_top" href="id/text/swriter/guide/references.html">Memperbaharui Referensi Silang</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/hyperlinks.html">Inserting Hyperlinks With the Navigator</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0222"><label for="0222">Mencetak</label><ul>\
    <li><a target="_top" href="id/text/swriter/guide/printer_tray.html">Selecting printer paper trays</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/print_preview.html">Previewing a Page Before Printing</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/print_small.html">Printing Multiple Pages on One Sheet</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/pagestyles.html">Creating and Applying Page Styles</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0223"><label for="0223">Mencari dan Mengganti</label><ul>\
    <li><a target="_top" href="id/text/swriter/guide/search_regexp.html">Using Wildcards in Text Searches</a></li>\
    <li><a target="_top" href="id/text/shared/01/02100001.html">List of Regular Expressions</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="06"><label for="06">Dokumen HTML</label><ul>\
    <li><a target="_top" href="id/text/shared/07/09000000.html">Halaman Web</a></li>\
    <li><a target="_top" href="id/text/shared/02/01170700.html">HTML Filters and Forms</a></li>\
    <li><a target="_top" href="id/text/swriter/guide/send2html.html">Menyimpan Dokumen Teks dalam Format HTML</a></li>\
	</ul></li></ul>\
';
